@@ -85,7 +85,7 @@ xkl_engine_is_group_per_toplevel_window(XklEngine * engine)
 static void
 xkl_engine_set_switch_to_secondary_group(XklEngine * engine, gboolean val)
 {
-	CARD32 propval = (CARD32) val;
+	gulong propval = (gulong) val == TRUE;
 	Display *dpy = xkl_engine_get_display(engine);
 	XChangeProperty(dpy,
 			xkl_engine_priv(engine, root_window),
@@ -413,7 +413,7 @@ xkl_default_log_appender(const gchar file[], const gchar function[],
 			 gint level, const gchar format[], va_list args)
 {
 	time_t now = time(NULL);
-	fprintf(stdout, "[%08ld,%03d,%s:%s/] \t", now, level, file,
+	fprintf(stdout, "[%08ld,%03d,%s:%s/] \t", (long)now, level, file,
 		function);
 	vfprintf(stdout, format, args);
 }
